==> r2r-3.2.8.tar.gz: r2r-3.2.8/shared/abstractions/__init__.py <==
from .base import AsyncSyncMeta, R2RSerializable, syncable
from .completion import CompletionRecord, MessageType
from .document import (
    DataType,
    Document,
    DocumentExtraction,
    DocumentInfo,
    DocumentType,
    IngestionStatus,
    KGEnrichmentStatus,
    KGExtractionStatus,
    RawChunk,
)
from .embedding import EmbeddingPurpose, default_embedding_prefixes
from .exception import R2RDocumentProcessingError, R2RException
from .graph import (
    Community,
    CommunityReport,
    Entity,
    EntityType,
    KGExtraction,
    RelationshipType,
    Triple,
)
from .kg import KGCreationSettings, KGEnrichmentSettings, KGRunType
from .llm import (
    GenerationConfig,
    LLMChatCompletion,
    LLMChatCompletionChunk,
    Message,
    RAGCompletion,
)
from .prompt import Prompt
from .search import (
    AggregateSearchResult,
    HybridSearchSettings,
    KGCommunityResult,
    KGEntityResult,
    KGGlobalResult,
    KGRelationshipResult,
    KGSearchMethod,
    KGSearchResult,
    KGSearchResultType,
    KGSearchSettings,
    VectorSearchResult,
    VectorSearchSettings,
)
from .user import Token, TokenData, UserStats
from .vector import StorageResult, Vector, VectorEntry, VectorType

__all__ = [
    # Base abstractions
    "R2RSerializable",
    "AsyncSyncMeta",
    "syncable",
    # Completion abstractions
    "CompletionRecord",
    "MessageType",
    # Document abstractions
    "DataType",
    "Document",
    "DocumentExtraction",
    "DocumentInfo",
    "IngestionStatus",
    "KGExtractionStatus",
    "KGEnrichmentStatus",
    "DocumentType",
    "RawChunk",
    # Embedding abstractions
    "EmbeddingPurpose",
    "default_embedding_prefixes",
    # Exception abstractions
    "R2RDocumentProcessingError",
    "R2RException",
    # Graph abstractions
    "Entity",
    "EntityType",
    "RelationshipType",
    "Community",
    "CommunityReport",
    "KGExtraction",
    "Triple",
    # LLM abstractions
    "GenerationConfig",
    "LLMChatCompletion",
    "LLMChatCompletionChunk",
    "Message",
    "RAGCompletion",
    # Prompt abstractions
    "Prompt",
    # Search abstractions
    "AggregateSearchResult",
    "KGSearchResult",
    "KGSearchMethod",
    "KGSearchResultType",
    "KGEntityResult",
    "KGRelationshipResult",
    "KGCommunityResult",
    "KGGlobalResult",
    "KGSearchSettings",
    "VectorSearchResult",
    "VectorSearchSettings",
    "HybridSearchSettings",
    # KG abstractions
    "KGCreationSettings",
    "KGEnrichmentSettings",
    "KGExtraction",
    "KGRunType",
    # User abstractions
    "Token",
    "TokenData",
    "UserStats",
    # Vector abstractions
    "Vector",
    "VectorEntry",
    "VectorType",
    "StorageResult",
]

==> r2r-3.2.36.tar.gz: r2r-3.2.36/shared/abstractions/__init__.py <==
from .base import AsyncSyncMeta, R2RSerializable, syncable
from .document import (
    DataType,
    Document,
    DocumentExtraction,
    DocumentInfo,
    DocumentType,
    IngestionStatus,
    KGEnrichmentStatus,
    KGExtractionStatus,
    RawChunk,
)
from .embedding import EmbeddingPurpose, default_embedding_prefixes
from .exception import R2RDocumentProcessingError, R2RException
from .graph import (
    Community,
    CommunityReport,
    Entity,
    EntityType,
    KGExtraction,
    RelationshipType,
    Triple,
)
from .kg import (
    KGCreationSettings,
    KGEnrichmentSettings,
    KGEntityDeduplicationSettings,
    KGRunType,
)
from .llm import (
    GenerationConfig,
    LLMChatCompletion,
    LLMChatCompletionChunk,
    Message,
    MessageType,
    RAGCompletion,
)
from .prompt import Prompt
from .search import (
    AggregateSearchResult,
    HybridSearchSettings,
    KGCommunityResult,
    KGEntityResult,
    KGGlobalResult,
    KGRelationshipResult,
    KGSearchMethod,
    KGSearchResult,
    KGSearchResultType,
    KGSearchSettings,
    VectorSearchResult,
    VectorSearchSettings,
)
from .user import Token, TokenData, UserStats
from .vector import (
    IndexArgsHNSW,
    IndexArgsIVFFlat,
    IndexMeasure,
    IndexMethod,
    StorageResult,
    Vector,
    VectorEntry,
    VectorQuantizationType,
    VectorTableName,
    VectorType,
)

__all__ = [
    # Base abstractions
    "R2RSerializable",
    "AsyncSyncMeta",
    "syncable",
    # Completion abstractions
    "MessageType",
    # Document abstractions
    "DataType",
    "Document",
    "DocumentExtraction",
    "DocumentInfo",
    "IngestionStatus",
    "KGExtractionStatus",
    "KGEnrichmentStatus",
    "DocumentType",
    "RawChunk",
    # Embedding abstractions
    "EmbeddingPurpose",
    "default_embedding_prefixes",
    # Exception abstractions
    "R2RDocumentProcessingError",
    "R2RException",
    # Graph abstractions
    "Entity",
    "EntityType",
    "RelationshipType",
    "Community",
    "CommunityReport",
    "KGExtraction",
    "Triple",
    # LLM abstractions
    "GenerationConfig",
    "LLMChatCompletion",
    "LLMChatCompletionChunk",
    "Message",
    "RAGCompletion",
    # Prompt abstractions
    "Prompt",
    # Search abstractions
    "AggregateSearchResult",
    "KGSearchResult",
    "KGSearchMethod",
    "KGSearchResultType",
    "KGEntityResult",
    "KGRelationshipResult",
    "KGCommunityResult",
    "KGGlobalResult",
    "KGSearchSettings",
    "VectorSearchResult",
    "VectorSearchSettings",
    "HybridSearchSettings",
    # KG abstractions
    "KGCreationSettings",
    "KGEnrichmentSettings",
    "KGExtraction",
    "KGRunType",
    # User abstractions
    "Token",
    "TokenData",
    "UserStats",
    # Vector abstractions
    "Vector",
    "VectorEntry",
    "VectorType",
    "IndexMethod",
    "IndexMeasure",
    "IndexArgsIVFFlat",
    "IndexArgsHNSW",
    "VectorTableName",
    "VectorQuantizationType",
    "StorageResult",
]
